function [OUTEEG, com] = pop_icablinkmetrics(INEEG)

    if isobject(INEEG) % eegobj
        disp('Error in pop_icablinkmetrics(): This function is not designed to work with the EEG object.')
        beep
    else
        if isempty(INEEG)
            disp('Error in pop_icablinkmetrics(): This function cannot run on an empty EEG dataset.')
            beep
        else
            if isempty(INEEG.data)
                disp('Error in pop_icablinkmetrics(): This function cannot run on an empty EEG dataset.')
                beep
            else

                % Prepare List of Current Channels in EEG.data
                listch = cell(1,size(INEEG.chanlocs,2)+1);
                listch{1} = '';
                for ch =1:size(INEEG.chanlocs,2)
                        listch{ch+1} = [num2str(ch) ' = ' INEEG.chanlocs(ch).labels ];
                end
                % Prepare List of Current Channels in EEG.skipchannels
                try
                    listch2 = cell(1,size(INEEG.skipchannels.labels,2)+1);
                    listch2{1} = '';
                    for ch =1:size(INEEG.skipchannels.labels,2)
                            listch2{ch+1} = [num2str(ch) ' = ' INEEG.skipchannels.labels{ch} ];
                    end
                catch
                    listch2=[ 'No Channels Available' ];
                end
                
                g1 = [0.5 0.5 ];
                g2 = [0.05 0.475 0.475];
                s1 = [1];
                geometry = { s1 g2 g2 g2 s1 g1 g1 s1 g1 g1 s1 s1 g2 g2 g2 s1};
                uilist = { ...
                      { 'Style', 'text', 'string', 'Channel Artifact Manifests In'} ...
                      ...
                      { } ...
                      { 'Style', 'text', 'string', 'Channel in EEG.data'  } ...
                      { 'Style', 'popupmenu', 'string', listch 'tag' 'EEGDATA' } ...
                      ...
                      { } ...
                      { 'Style', 'text', 'string', '         or'  } ...
                      { } ...
                      ...
                      { } ...
                      { 'Style', 'text', 'string', 'Channel in EEG.skipchannels'  } ...
                      { 'Style', 'popupmenu', 'string', listch2 'tag' 'EEGSKIP' } ...
                      ...
                      { } ...
                      ...
                      { 'Style', 'text', 'string', 'Window Surrounding Artifact'} ...
                      { 'Style', 'edit', 'string', '[-150, 150]' 'tag' 'Window'  } ...
                      ...
                      { } ...
                      { 'Style', 'text', 'string', 'format: [window start, window stop]'} ...
                      ...
                      { } ...
                      ...
                      { 'Style', 'text', 'string', 'Minimum Number of Artifacts'} ...
                      { 'Style', 'edit', 'string', '5' 'tag' 'Minimum'  } ...
                      ...
                      { } ...
                      { 'Style', 'text', 'string', 'format: integer value'} ...
                      ...
                      { } ...
                      ...
                      { 'Style', 'text', 'string', 'Thresholds for Artifact Selection (entering NaN will skip that metric) '} ...
                      ...
                      { } ...
                      { 'Style', 'text', 'string', 'Correlation Threshold'} ...
                      { 'Style', 'edit', 'string', '0.6' 'tag' 'Correlation'  } ...
                      ...
                      { } ...
                      { 'Style', 'text', 'string', 'Convolution Threshold'} ...
                      { 'Style', 'edit', 'string', '0.4' 'tag' 'Convolution'  } ...
                      ...
                      { } ...
                      { 'Style', 'text', 'string', 'PercentReduction Threshold'} ...
                      { 'Style', 'edit', 'string', '25' 'tag' 'PercentReduction'  } ...
                      ...
                      { } ...
                      ...
                  };

                  [ tmp1 tmp2 strhalt structout ] = inputgui( geometry, uilist, 'pophelp(''icablinkmetrics'');', 'Compute ICA Eye Blink Metrics -- pop_icablinkmetrics');
                  OUTEEG = INEEG;
                  if ~isempty(structout)
                      structout.Minimum = str2num(structout.Minimum);
                      structout.Correlation = str2num(structout.Correlation);
                      structout.Convolution = str2num(structout.Convolution);
                      structout.PercentReduction = str2num(structout.PercentReduction);
                      structout.Window = str2num(structout.Window);
                      if (structout.EEGDATA > 1)
                          OUTEEG.icaquant = icablinkmetrics(INEEG,'ArtifactChannel',INEEG.data(structout.EEGDATA-1,:),'Window',structout.Window,'MinimumArtifacts',structout.Minimum,'MetricThresholds',[structout.Correlation,structout.Convolution,structout.PercentReduction]);
                          com = sprintf('\nEquivalent Code:\n\t%s.icaquant = icablinkmetrics(%s, ''ArtifactChannel'',EEG.data(%d,:), ''Window'', %s, ''MinimumArtifacts'', %d, ''MetricThresholds'', %s);\n', inputname(1), inputname(1), (structout.EEGDATA-1),mat2str(structout.Window),structout.Minimum,mat2str([structout.Correlation,structout.Convolution,structout.PercentReduction]));
                          disp(com)
                          disp('ICA Metrics are located in:    EEG.icaquant.metrics')
                          if (OUTEEG.icaquant.thresholdedcomponents ~= 0)
                              if (size(OUTEEG.icaquant.thresholdedcomponents,2) > 1)
                                  com = sprintf('Components %s were identified as exhibiting above threshold values and are candidates for removal.\n',mat2str(OUTEEG.icaquant.thresholdedcomponents));
                              else
                                  com = sprintf('Component %d was identified as exhibiting above threshold values and is a candidate for removal.\n',OUTEEG.icaquant.thresholdedcomponents);
                              end
                          else
                              com = sprintf('No components exhibited above threshold values.\n');
                          end
                          disp(com)
                      else
                          if (structout.EEGSKIP > 1)
                              OUTEEG.icaquant = icablinkmetrics(INEEG,'ArtifactChannel',INEEG.skipchannels.data(structout.EEGSKIP-1,:),'Window',structout.Window,'MinimumArtifacts',structout.Minimum,'MetricThresholds',[structout.Correlation,structout.Convolution,structout.PercentReduction]);
                              com = sprintf('\nEquivalent Code:\n\t%s.icaquant = icablinkmetrics(%s, ''ArtifactChannel'',EEG.skipchannels.data(%d,:), ''Window'', %s, ''MinimumArtifacts'', %d, ''MetricThresholds'', %s);\n', inputname(1), inputname(1), (structout.EEGSKIP-1),mat2str(structout.Window),structout.Minimum,mat2str([structout.Correlation,structout.Convolution,structout.PercentReduction]));
                              disp(com)
                              disp('ICA Metrics are located in:    EEG.icaquant.metrics')
                              if (OUTEEG.icaquant.thresholdedcomponents ~= 0)
                                  if (size(OUTEEG.icaquant.thresholdedcomponents,2) > 1)
                                      com = sprintf('Components %s were identified as exhibiting above threshold values and are candidates for removal.\n',mat2str(OUTEEG.icaquant.thresholdedcomponents));
                                  else
                                      com = sprintf('Component %d was identified as exhibiting above threshold values and is a candidate for removal.\n',OUTEEG.icaquant.thresholdedcomponents);
                                  end
                              else
                                  com = sprintf('No components exhibited above threshold values.\n');
                              end
                              disp(com)
                          else
                              fprintf('\n\nError in pop_icablinkmetrics(): No Artifact Channel Selected.\n\n')
                              beep
                              com = '';
                          end
                      end
                  else
                      com = '';
                  end
            end
        end
    end
end